@@ -1,41 +1,41 @@
 import base64
 import io
 import itertools
+import logging
 import os
 import shutil
-import logging
-from datetime import datetime, timedelta, date
+from datetime import timedelta, date
 from decimal import Decimal
-from uuid import UUID
 from zipfile import ZipFile
 
 from PySimpleGUI import POPUP_BUTTONS_OK_CANCEL, PySimpleGUI
 from markdown2 import markdown
 from satcfdi import DatePeriod, CFDI, Code, Signer
 from satcfdi.accounting import filter_invoices_iter, SatCFDI
-from satcfdi.create import Issuer
+from satcfdi.create.cfd import cfdi40
 from satcfdi.exceptions import ResponseError, DocumentNotFoundError
 from satcfdi.pacs import Accept
 from satcfdi.pacs.sat import SAT, TipoDescargaMasivaTerceros, EstadoSolicitud
 # noinspection PyUnresolvedReferences
 from satcfdi.transform.catalog import CATALOGS
-
 from weasyprint import HTML, CSS
 
-from . import SOURCE_DIRECTORY, __version__, local
+from . import SOURCE_DIRECTORY, __version__
 from .client_validation import validar_client
-from .file_data_managers import environment_default, environment_bold_escaped, ClientsManager, ConfigManager
+from .file_data_managers import environment_default, environment_bold_escaped, ClientsManager, ConfigManager, FacturasManager
 from .formatting_functions.common import fecha, pesos, porcentaje
 from .gui_functions import generate_ingresos, pago_factura, find_ajustes, format_concepto_desc, exportar_facturas, exportar_facturas_filename, parse_ym_date
 from .layout import make_layout, InvoiceButtonManager, EmailButtonManager
-from .log_tools import log_line, log_item, cfdi_header, print_yaml
-from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder, local_db, PPD, PUE
-
+from .local import LocalDBSatCFDI
+from .log_tools import log_line, log_item, cfdi_header, print_yaml, header_line
+from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder, PPD, PUE
+from .utils import random_string, to_uuid, add_file_handler, convert_ans1_date
 
 logging.getLogger("weasyprint").setLevel(logging.ERROR)
 logging.getLogger("fontTools").setLevel(logging.ERROR)
 
 logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
 
 AJUSTES_DIR = "ajustes"
 template = environment_default.get_template(
@@ -43,87 +43,97 @@ template = environment_default.get_template(
 )
 
 
-def is_uuid(s):
-    try:
-        UUID(s)
-        return True
-    except ValueError:
-        return False
-
-
 class FacturacionGUI:
-    def __init__(self, pac_service, csd_signer: Signer, email_manager, fiel_signer=None, concepto_adapter=None, debug=False):
+    def __init__(self, pac_service, csd_signer: Signer, email_manager, fiel_signer=None, debug=False):
+        # set up logging
+        if debug:
+            logging.basicConfig(level=logging.ERROR)
+        add_file_handler()
+
         self.email_manager = email_manager
         self.pac_service = pac_service
         self.sat_service = SAT(
             signer=fiel_signer
         )
-        self.concepto_adapter = concepto_adapter
-        clients = ClientsManager()
+        self.csd_signer = csd_signer
 
-        self.issuer_cif = clients[csd_signer.rfc]
-        self.lugar_expedicion = self.issuer_cif['CodigoPostal']
-        self.issuer = Issuer(
-            signer=csd_signer,
-            tax_system=self.issuer_cif['RegimenFiscal'],
-            legal_name=self.issuer_cif['RazonSocial']
-        )
-
-        MyCFDI.issuer_rfc = self.issuer.rfc
-        window = PySimpleGUI.Window(
-            f"Facturacion 4.0  RazonSocial: {self.issuer.legal_name}  RFC: {self.issuer.rfc}  "
-            f"Serie: {local.config.serie()}  Regimen: {self.issuer.tax_system}  LugarExpedicion: {self.lugar_expedicion}",
-            make_layout(fiel_signer is not None, debug=debug),
+        self.window = PySimpleGUI.Window(
+            f"Facturacion 4.0",
+            make_layout(fiel_signer is not None),
             size=(1280, 800),
             resizable=True,
         )
-        self.window = window
-        self.console = self.window['console']
 
-        self.invoice_button_manager = InvoiceButtonManager(window["crear_facturas"], window["detallado"])
-        self.email_button_manager = EmailButtonManager(window["enviar_correos"])
         self.all_invoices = None
+        self.config = None
+        self.local_db = None
+        self.base_template = None
+        self.issuer_cif = None
+
+        self.invoice_button_manager = InvoiceButtonManager(self.window["crear_facturas"], self.window["detallado"])
+        self.email_button_manager = EmailButtonManager(self.window["enviar_correos"])
+        self.console = self.window["console"]
+
+    def prepare(self):
+        clients = ClientsManager()
+        self.config = ConfigManager()
+        self.local_db = LocalDBSatCFDI(self.config)
+
+        issuer_cif = clients[self.csd_signer.rfc]
+        self.issuer_cif = issuer_cif
+
+        self.base_template = {
+            "Emisor": cfdi40.Emisor(
+                rfc=issuer_cif['Rfc'],
+                nombre=issuer_cif['RazonSocial'],
+                regimen_fiscal=issuer_cif['RegimenFiscal']
+            ),
+            "LugarExpedicion": issuer_cif['CodigoPostal']
+        }
+
+        MyCFDI.issuer_rfc = self.csd_signer.rfc
+        MyCFDI.local_db = self.local_db
+
+        # update window title
+        self.window.set_title(
+            f"Facturacion 4.0  RFC: {self.csd_signer.rfc}  RazonSocial: {issuer_cif['RazonSocial']}  RegimenFiscal: {issuer_cif['RegimenFiscal']}  "
+            f"LugarExpedicion: {issuer_cif['CodigoPostal']}"
+        )
 
     def initial_screen(self):
-        def convert_ans1_date(ans1_date):
-            return datetime.strptime(ans1_date.decode('utf-8'), '%Y%m%d%H%M%SZ')
-
-        def cert_info(signer: Signer):
-            if signer:
-                return {
-                    "NoCertificado": signer.certificate_number,
-                    "Tipo": str(signer.type),
-
-                    "organizationName": signer.certificate.get_subject().O,
-                    "x500UniqueIdentifier": signer.certificate.get_subject().x500UniqueIdentifier,
-                    "serialNumber": signer.certificate.get_subject().serialNumber,
-                    "organizationUnitName": signer.certificate.get_subject().OU,
-                    "emailAddress": signer.certificate.get_subject().emailAddress,
-
-                    "notAfter": convert_ans1_date(signer.certificate.get_notAfter()),
-                    "notBefore": convert_ans1_date(signer.certificate.get_notBefore()),
-                }
-
-        try:
-            print_yaml({
-                "version": __version__.__version__,
-                "facturacion": "CFDI 4.0",
-                "emisor": self.issuer_cif,
-                "pac_service": {
-                    "Type": type(self.pac_service).__name__,
-                    "Rfc": self.pac_service.RFC,
-                    "Environment": str(self.pac_service.environment)
-                },
-                "csd_signer": cert_info(self.issuer.signer),
-                "fiel_signer": cert_info(self.sat_service.signer),
-                "config": local.config,
-            })
-        except Exception as ex:
-            logger.exception("Error al obtener datos")
+        print_yaml({
+            "version": __version__.__version__,
+            "facturacion": "CFDI 4.0",
+            "emisor": self.base_template,
+            "pac_service": {
+                "Type": type(self.pac_service).__name__,
+                "Rfc": self.pac_service.RFC,
+                "Environment": str(self.pac_service.environment)
+            }
+        })
 
     def start(self):
         self.window.finalize()
-        self.initial_screen()
+
+        # Add logging to the window
+        h = logging.StreamHandler(self.window['console'])
+        h.setLevel(logging.INFO)
+        logger.addHandler(h)
+
+        try:
+            self.prepare()
+            self.initial_screen()
+        except Exception:
+            logger.exception(header_line("ERROR"))
+            for e in self.window.element_list():
+                if isinstance(e, PySimpleGUI.Button):
+                    e.update(disabled=True)
+                if isinstance(e, PySimpleGUI.Input):
+                    e.update("", disabled=True)
+            self.window.read()
+            self.window.close()
+            return
+
         self.main_loop()
         self.window.close()
 
@@ -133,44 +143,61 @@ class FacturacionGUI:
         self.all_invoices = get_all_cfdi()
         return self.all_invoices
 
-    def generate_invoice(self, invoice, ref_id=None):
-        res = self.pac_service.stamp(
-            cfdi=invoice,
-            accept=Accept.XML_PDF,
-            ref_id=ref_id
-        )
-        local.config.inc_folio()
-        return move_to_folder(res.xml, pdf_data=res.pdf)
+    def generate_invoice(self, invoice):
+        ref_id = random_string()
+
+        attempts = 3
+        for i in range(attempts):
+            if i:
+                print(f'Intentando de nuevo... Intento {i + 1} de {attempts}')
+                self._read(timeout=1000 * i)
+
+            try:
+                res = self.pac_service.stamp(
+                    cfdi=invoice,
+                    accept=Accept.XML_PDF,
+                    ref_id=ref_id
+                )
+            except Exception as ex:
+                logger.error(f'Error Generando: {cfdi_header(MyCFDI(invoice))}')
+                if isinstance(ex, ResponseError):
+                    logger.error(f"Status Code: {ex.response.status_code}")
+                    logger.error(f"Response: {ex.response.text}")
+                continue
+
+            self.config.inc_folio()
+            return move_to_folder(res.xml, pdf_data=res.pdf)
 
     def enviar_correos(self, emails):
         with self.email_manager.sender as s:
-            for receptor, notify_invoices, facturas_pendientes in emails:
-                receptor_nombre = receptor["RazonSocial"]
-                to_addrs = receptor["Email"]
-
+            for receptor, notify_invoices, pendientes_meses_anteriores in emails:
                 attachments = []
                 for r in notify_invoices:
                     attachments += [r.filename + ".xml", r.filename + ".pdf"]
 
-                message = self.generate_html_template(
-                    'mail_facturas_template.html',
-                    fields={
-                        'invoices': notify_invoices,
-                        'pending_invoices': facturas_pendientes,
-                    }
-                )
-
+                subject = f"Comprobantes Fiscales {receptor['RazonSocial']} - {receptor['Rfc']}"
                 s.send_email(
-                    subject=f"Comprobantes Fiscales {receptor_nombre} - {receptor['Rfc']}",
-                    to_addrs=to_addrs,
-                    html=message,
+                    subject=subject,
+                    to_addrs=receptor["Email"],
+                    html=self.generate_html_template(
+                        'mail_facturas_template.html',
+                        fields={
+                            "facturas": notify_invoices,
+                            'pendientes_meses_anteriores': pendientes_meses_anteriores,
+                        }
+                    ),
                     file_attachments=attachments
                 )
-
-                self._read()
-
                 for r in notify_invoices:
-                    r.notified = ",".join(to_addrs)
+                    r.notified = True
+
+                print_yaml({
+                    "correo_enviado": subject,
+                    'facturas': [f"{i.name} - {i.uuid}" for i in notify_invoices],
+                    'pendientes_meses_anteriores': [f"{i.name} - {i.uuid}" for i in pendientes_meses_anteriores],
+                    "correos": receptor["Email"]
+                })
+                self._read()
 
     def recupera_comprobantes(self, id_solicitud):
         response = self.sat_service.recover_comprobante_status(
@@ -194,11 +221,11 @@ class FacturacionGUI:
                 move_to_folder(xml_data, pdf_data=None)
                 self._read()
 
-    def _read(self):
-        event, values = self.window.read(timeout=0)
+    def _read(self, timeout=0):
+        event, values = self.window.read(timeout=timeout)
         if event in ("Exit", PySimpleGUI.WIN_CLOSED):
             exit(0)
-        
+
     def generate_pdf_template(self, template_name, fields):
         increment_template = environment_bold_escaped.get_template(template_name)
         md5_document = increment_template.render(
@@ -226,28 +253,22 @@ class FacturacionGUI:
         return render
 
     def factura_uuid(self, text):
-        try:
-            factura_uuid = UUID(text)
-            factura = self.get_all_invoices().get(factura_uuid)
-            if factura:
-                return factura
-        except:
-            pass
+        return self.get_all_invoices().get(to_uuid(text))
 
     def factura_buscar(self, text):
         if text:
-            emisor_rfc = self.issuer.rfc
+            emisor_rfc = self.csd_signer.rfc
             res = None
             for i in self.get_all_invoices().values():
                 if i.name == text and i["Emisor"]["Rfc"] == emisor_rfc:
-                    print(f"Factura Encontrada: {i['Receptor']['Rfc']}  {i.name}  {i.uuid}  {i['Fecha']}")
+                    logger.info(f"Factura Encontrada: {i['Receptor']['Rfc']}  {i.name}  {i.uuid}  {i['Fecha']}")
                     if res:
-                        print(f"Multiples Facturas Encontradas con el mismo nombre: {text}")
+                        logger.info(f"Multiples Facturas Encontradas con el mismo nombre: {text}")
                         return
                     res = i
             if res:
                 return res
-        print(f"Factura No Encontrada {text}")
+        logger.info(f"Factura No Encontrada {text}")
 
     def log_cfdi(self, cfdi: CFDI, ver_saldo=True):
         cfdi_copy = cfdi.copy()
@@ -309,7 +330,7 @@ class FacturacionGUI:
 
         while True:
             event, values = self.window.read()
-            local.config = ConfigManager()
+            self.config.reload()
             try:
                 if event in ("Exit", PySimpleGUI.WIN_CLOSED):
                     return
@@ -331,33 +352,33 @@ class FacturacionGUI:
 
                         if factura_seleccionada:
                             self.log_cfdi(factura_seleccionada)
-                            local_db.describe(factura_seleccionada)
+                            self.local_db.describe(factura_seleccionada)
 
                         not_ppd_all = not factura_seleccionada \
                                       or factura_seleccionada.get("MetodoPago") != PPD \
                                       or factura_seleccionada.estatus != "1"
                         not_ppd = not_ppd_all \
-                                  or factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
+                                  or factura_seleccionada["Emisor"]["Rfc"] != self.csd_signer.rfc
 
                         not_pue = not factura_seleccionada \
                                   or factura_seleccionada.get("MetodoPago") != PUE \
                                   or factura_seleccionada.estatus != "1" or \
-                                  factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
+                                  factura_seleccionada["Emisor"]["Rfc"] != self.csd_signer.rfc
 
                         self.window["status_sat"].update(disabled=not factura_seleccionada)
 
                         self.window["pago_pue"].update(
                             disabled=not_pue
-                                     or factura_seleccionada["Fecha"] <= local.config['pue_pagada_hasta']
+                                     or factura_seleccionada["Fecha"] <= self.config['pue_pagada_hasta']
                         )
                         self.window["email_notificada"].update(
                             disabled=not factura_seleccionada
-                                     or factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
-                                     or factura_seleccionada["Fecha"] <= local.config['email_notificada_hasta']
+                                     or factura_seleccionada["Emisor"]["Rfc"] != self.csd_signer.rfc
+                                     or factura_seleccionada["Fecha"] <= self.config['email_notificada_hasta']
                         )
                         self.window["ignorar_ppd"].update(
                             disabled=not_ppd_all
-                                     or factura_seleccionada["Fecha"] <= local.config['ppd_ignorar_hasta']
+                                     or factura_seleccionada["Fecha"] <= self.config['ppd_ignorar_hasta']
                         )
 
                         self.window["ver_factura"].update(disabled=not factura_seleccionada)
@@ -366,14 +387,14 @@ class FacturacionGUI:
                         self.window["fecha_pago_select"].update(disabled=not_ppd)
                         self.window["fecha_pago"].update(disabled=not_ppd)
                         self.window["forma_pago"].update(disabled=not_ppd)
-                        self.window["descarga"].update(disabled=not is_uuid(text))
+                        self.window["descarga"].update(disabled=not to_uuid(text))
 
                     case "preparar_ajuste_anual":
                         log_item(f"AJUSTE ANUAL")
                         ym_date = parse_ym_date(values['anio_mes_ajuste'])
                         ajuste_porcentaje = values['ajuste_porcentaje']
                         if not ajuste_porcentaje:
-                            logger.error("Especificar Ajuste Porcetaje")
+                            logger.info("Especificar Ajuste Porcetaje")
                             continue
 
                         ajuste_porcentaje = Decimal(ajuste_porcentaje) / 100
@@ -381,13 +402,14 @@ class FacturacionGUI:
                         shutil.rmtree(AJUSTES_DIR, ignore_errors=True)
                         os.makedirs(AJUSTES_DIR, exist_ok=True)
                         clients = ClientsManager()
+                        facturas = FacturasManager()["Facturas"]
 
                         has_ajustes = False
-                        for i, (rfc, concepto) in enumerate(find_ajustes(ym_date.month), start=1):
+                        for i, (rfc, concepto) in enumerate(find_ajustes(facturas, ym_date.month), start=1):
                             has_ajustes = True
                             receptor = clients[rfc]
                             valor_unitario_nuevo = concepto["ValorUnitario"] * (1 + ajuste_porcentaje)
-                            format_concepto_desc(concepto, periodo="INMUEBLE")
+                            concepto = format_concepto_desc(concepto, periodo="INMUEBLE")
 
                             data = {
                                 "receptor": receptor,
@@ -416,7 +438,7 @@ class FacturacionGUI:
                         log_line("RECUPERAR")
                         fecha_final = date.today()
                         fecha_inicial = fecha_final - timedelta(days=int(values["recuperar_dias"]))
-                        id_solicitud = local.config.get(event)
+                        id_solicitud = self.config.get(event)
 
                         if not id_solicitud:
                             self._read()
@@ -428,8 +450,8 @@ class FacturacionGUI:
                                 tipo_solicitud=TipoDescargaMasivaTerceros.CFDI,
                             )
                             print_yaml(response)
-                            local.config[event] = response['IdSolicitud']
-                            local.config.save()
+                            self.config[event] = response['IdSolicitud']
+                            self.config.save()
                             print("Nueva Solicitud Creada")
                         else:
                             print_yaml({
@@ -441,8 +463,8 @@ class FacturacionGUI:
                                     self.all_invoices = None
                                     with io.BytesIO(data) as b:
                                         self.unzip_cfdi(b)
-                                del local.config[event]
-                                local.config.save()
+                                del self.config[event]
+                                self.config.save()
 
                     case "validate_clientes":
                         log_line("VALIDAR CLIENTES")
@@ -463,7 +485,14 @@ class FacturacionGUI:
 
                     case "prepare_facturas":
                         log_line("PREPARAR FACTURAS")
-                        facturas = generate_ingresos(values, self.issuer, self.lugar_expedicion, self.concepto_adapter)
+                        facturas = generate_ingresos(
+                            config=self.config,
+                            clients=ClientsManager(),
+                            facturas=FacturasManager()["Facturas"],
+                            values=values,
+                            csd_signer=self.csd_signer,
+                            base_template=self.base_template
+                        )
                         if facturas:
                             for i, cfdi in enumerate(facturas, start=1):
                                 log_item(f"FACTURA NUMERO: {i}")
@@ -477,11 +506,12 @@ class FacturacionGUI:
                         log_line("COMPROBANTE PAGO")
                         if i := factura_seleccionada:
                             cfdi_pago = pago_factura(
+                                config=self.config,
                                 factura_pagar=i,
                                 fecha_pago=values["fecha_pago"],
                                 forma_pago=values["forma_pago"],
-                                issuer=self.issuer,
-                                lugar_expedicion=self.lugar_expedicion
+                                csd_signer=self.csd_signer,
+                                lugar_expedicion=self.base_template["LugarExpedicion"]
                             )
                             if cfdi_pago:
                                 self.log_cfdi(cfdi_pago)
@@ -498,15 +528,15 @@ class FacturacionGUI:
                     case "status_sat":
                         log_line("STATUS")
                         if i := factura_seleccionada:
-                            estado = local_db.status_sat(i, update=True)
+                            estado = self.local_db.status_sat(i, update=True)
                             print_yaml(estado)
-                            local_db.describe(i)
+                            self.local_db.describe(i)
 
                     case "pago_pue":
                         if i := factura_seleccionada:
                             self.log_cfdi(i)
-                            local_db.describe(i)
-                            st = local_db.pue_pagada(i)
+                            self.local_db.describe(i)
+                            st = self.local_db.pue_pagada(i)
                             res = PySimpleGUI.popup(
                                 f"Estas seguro que quieres marcarla como {'-NO- ' if st else ''}pagada?",
                                 title=self.window[event].ButtonText,
@@ -514,16 +544,16 @@ class FacturacionGUI:
                             )
                             if res == "OK":
                                 self.console.update("")
-                                local_db.pue_pagada_set(i.uuid, not st)
+                                self.local_db.pue_pagada_set(i.uuid, not st)
                                 self.log_cfdi(i)
-                                local_db.describe(i)
+                                self.local_db.describe(i)
                                 print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}PAGADA")
 
                     case "ignorar_ppd":
                         if i := factura_seleccionada:
                             self.log_cfdi(i)
-                            local_db.describe(i)
-                            st = local_db.ppd_ignorar(i)
+                            self.local_db.describe(i)
+                            st = self.local_db.ppd_ignorar(i)
                             res = PySimpleGUI.popup(
                                 f"Estas seguro que quieres marcarla como {'-NO- ' if st else ''}ignorada?",
                                 title=self.window[event].ButtonText,
@@ -531,16 +561,16 @@ class FacturacionGUI:
                             )
                             if res == "OK":
                                 self.console.update("")
-                                local_db.ppd_ignorar_set(i.uuid, not st)
+                                self.local_db.ppd_ignorar_set(i.uuid, not st)
                                 self.log_cfdi(i)
-                                local_db.describe(i)
+                                self.local_db.describe(i)
                                 print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}IGNORADA")
 
                     case "email_notificada":
                         if i := factura_seleccionada:
                             self.log_cfdi(i)
-                            local_db.describe(i)
-                            st = local_db.email_notificada(i)
+                            self.local_db.describe(i)
+                            st = self.local_db.email_notificada(i)
                             res = PySimpleGUI.popup(
                                 f"Estas seguro que quieres marcarla como {'-NO- ' if st else ''}notificada?",
                                 title=self.window[event].ButtonText,
@@ -548,9 +578,9 @@ class FacturacionGUI:
                             )
                             if res == "OK":
                                 self.console.update("")
-                                local_db.email_notificada_set(i.uuid, not st)
+                                self.local_db.email_notificada_set(i.uuid, not st)
                                 self.log_cfdi(i)
-                                local_db.describe(i)
+                                self.local_db.describe(i)
                                 print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}NOTIFICADA")
 
                     case "crear_facturas":
@@ -563,17 +593,13 @@ class FacturacionGUI:
                         if res == "OK":
                             self.all_invoices = None
                             for invoice in invoices_to_create:
-                                try:
-                                    cfdi = self.generate_invoice(invoice=invoice)
-                                    print_yaml({
-                                        "FacturaGenerada": cfdi_header(cfdi),
-                                    })
-                                    self._read()
-                                except ResponseError as ex:
-                                    logger.error(f'Error Generando: {cfdi_header(MyCFDI(invoice))}')
-                                    logger.error(f"Status Code: {ex.response.status_code}")
-                                    print_yaml(ex.response.json())
+                                cfdi = self.generate_invoice(invoice=invoice)
+                                if cfdi is None:
                                     break
+                                print_yaml({
+                                    "FacturaGenerada": cfdi_header(cfdi),
+                                })
+                                self._read()
                             log_item("FIN")
                         else:
                             log_item("OPERACION CANCELADA")
@@ -599,12 +625,12 @@ class FacturacionGUI:
                                 fecha=lambda x: x < dp,
                                 invoice_type="I",
                                 pending_balance=lambda x: x > 0,
-                                rfc_emisor=self.issuer.rfc,
+                                rfc_emisor=self.csd_signer.rfc,
                                 rfc_receptor=receptor_rfc,
                                 estatus='1'
                             )
                             receptor = clients[receptor_rfc]
-                            cfdi_correos.append((receptor, notify_invoices, list(fac_pen)))
+                            cfdi_correos.append((receptor, notify_invoices, sorted(fac_pen, key=lambda r: r["Fecha"])))
 
                         if cfdi_correos:
                             self.email_button_manager.set_emails(
@@ -634,7 +660,7 @@ class FacturacionGUI:
                             invoices=self.get_all_invoices().values(),
                             invoice_type="I",
                             pending_balance=lambda x: x > 0,
-                            rfc_emisor=self.issuer.rfc,
+                            rfc_emisor=self.csd_signer.rfc,
                             estatus='1'
                         )
                         for receptor_rfc, fac_pen in itertools.groupby(
@@ -652,7 +678,7 @@ class FacturacionGUI:
                                         'SaldoPendiente': i.saldo_pendiente,
                                         'Fecha': i["Fecha"]
                                     }
-                                    for i in fac_pen
+                                    for i in sorted(fac_pen, key=lambda r: r["Fecha"])
                                 ]
                             }
                             print_yaml(f)
@@ -665,11 +691,11 @@ class FacturacionGUI:
                             cfdi = move_to_folder(res.xml, pdf_data=res.pdf)
                             self.log_cfdi(cfdi, ver_saldo=False)
                         except DocumentNotFoundError:
-                            print("Factura no encontrada")
+                            logger.info("Factura no encontrada")
 
                     case "exportar_facturas":
                         log_line("EXPORTAR FACTURAS")
-                        exportar_facturas(self.get_all_invoices(), values["periodo"], self.issuer)
+                        exportar_facturas(self.get_all_invoices(), values["periodo"], self.csd_signer.rfc, self.issuer_cif['RegimenFiscal'])
 
                     case "ver_excel":
                         archivo_excel = exportar_facturas_filename(values["periodo"])
@@ -684,5 +710,4 @@ class FacturacionGUI:
                         logger.error(f"Unknown event '{event}'")
 
             except Exception as ex:
-                log_line("ERROR")
-                logger.exception(ex)
+                logger.exception(header_line("ERROR"))
