@@ -14,8 +14,7 @@ from satcfdi.pacs import sat
 from satcfdi.transform.catalog import CATALOGS
 from xlsxwriter.exceptions import FileCreateError
 
-from .file_data_managers import FacturasManager, ClientsManager, environment_default
-from .local import config
+from .file_data_managers import  environment_default
 
 logger = logging.getLogger(__name__)
 sat_manager = sat.SAT()
@@ -30,10 +29,10 @@ PERIODOS = {
 }
 
 
-def create_cfdi(client, factura_details, serie, folio, issuer, lugar_expedicion):
+def create_cfdi(client, factura_details, serie, folio, csd_sginer, base_template):
     invoice = cfdi40.Comprobante(
-        emisor=issuer,
-        lugar_expedicion=lugar_expedicion,
+        emisor=base_template["Emisor"],
+        lugar_expedicion=base_template["LugarExpedicion"],
         receptor=cfdi40.Receptor(
             rfc=factura_details['Rfc'],
             nombre=client['RazonSocial'],
@@ -46,10 +45,12 @@ def create_cfdi(client, factura_details, serie, folio, issuer, lugar_expedicion)
         serie=serie,
         folio=folio,
         conceptos=factura_details["Conceptos"]
-    ).process()
+    )
+    invoice.sign(csd_sginer)
+    invoice = invoice.process()
 
     if factura_details['Total'] != invoice['Total']:
-        logger.error(f"{factura_details['Rfc']}: Total '{factura_details['Total']}' is invalid, expected '{invoice['Total']}'")
+        logger.info(f"{factura_details['Rfc']}: Total '{factura_details['Total']}' is invalid, expected '{invoice['Total']}'")
         return None
 
     return invoice
@@ -87,10 +88,12 @@ def parse_date_period(periodo):
 
 
 def format_concepto_desc(concepto, periodo):
+    concepto = concepto.copy()
     template = environment_default.from_string(concepto["Descripcion"])
     concepto["Descripcion"] = template.render(
         periodo=periodo
     )
+    return concepto
 
 
 def validad_facturas(clients, facturas):
@@ -98,7 +101,7 @@ def validad_facturas(clients, facturas):
     for factura_details in facturas:
         cliente = clients.get(factura_details['Rfc'])
         if not cliente:
-            logger.error(f"{factura_details['Rfc']}: client not found")
+            logger.info(f"{factura_details['Rfc']}: client not found")
             is_valid = False
 
         if conceptos := factura_details.get("Conceptos"):
@@ -107,13 +110,13 @@ def validad_facturas(clients, facturas):
                 try:
                     parse_periodo_mes_ajuste(periodo_mes_ajuste)
                 except ValueError:
-                    logger.error(f"{factura_details['Rfc']}: _periodo_mes_ajuste '{periodo_mes_ajuste}' is invalid")
+                    logger.info(f"{factura_details['Rfc']}: _periodo_mes_ajuste '{periodo_mes_ajuste}' is invalid")
                     is_valid = False
         else:
-            logger.error(f"{factura_details['Rfc']}: no tienen conceptos")
+            logger.info(f"{factura_details['Rfc']}: no tienen conceptos")
 
         if factura_details["MetodoPago"] == "PPD" and factura_details["FormaPago"] != "99":
-            logger.error(f"{factura_details['Rfc']}: FormaPago '{factura_details['FormaPago']}' is invalid, expected '99' for PPD")
+            logger.info(f"{factura_details['Rfc']}: FormaPago '{factura_details['FormaPago']}' is invalid, expected '99' for PPD")
             is_valid = False
 
     return is_valid
@@ -123,8 +126,8 @@ def year_month_desc(year, month):
     return format_date(date(year=year, month=month, day=1), locale='es_MX', format="'Mes de' MMMM 'del' y").upper()
 
 
-def perpare_concepto(ym_date, concepto, concepto_adapter):
-    periodo, mes_ajuste = parse_periodo_mes_ajuste(concepto['_periodo_mes_ajuste'])
+def periodo_desc(ym_date, periodo_mes_ajuste):
+    periodo, mes_ajuste = parse_periodo_mes_ajuste(periodo_mes_ajuste)
     periodo_meses = PERIODOS[periodo]
 
     if (ym_date.month - mes_ajuste) % periodo_meses == 0:
@@ -136,41 +139,41 @@ def perpare_concepto(ym_date, concepto, concepto_adapter):
                 month=mes_final
             )
 
-        format_concepto_desc(concepto, periodo=periodo)
-        if concepto_adapter:
-            concepto_adapter(concepto)
-        return concepto
+        return periodo
     return None
 
 
-def generate_ingresos(values, issuer, lugar_expedicion, concepto_adapter):
-    clients = ClientsManager()
-    facturas = FacturasManager()["Facturas"]
+def generate_ingresos(config, clients, facturas, values, csd_signer, base_template):
     if not validad_facturas(clients, facturas):
         return
 
     inicio = int(values["inicio"])
     if inicio <= 0:
-        logger.error("Inicio no Valido")
+        logger.info("Inicio no Valido")
 
     final = values["final"] or len(facturas)
     final = int(final)
     if final <= 0 or final < inicio:
-        logger.error("Final no Valido")
+        logger.info("Final no Valido")
 
     ym_date = parse_ym_date(values["periodo"])
     facturas = facturas[inicio - 1:final]
     folio = config.folio()
     serie = config.serie()
 
+    def prepare_concepto(concepto):
+        periodo = periodo_desc(ym_date, concepto['_periodo_mes_ajuste'])
+        if periodo:
+            return format_concepto_desc(concepto, periodo=periodo)
+
     def facturas_iter():
         i = 0
         for f in facturas:
             client = clients[f['Rfc']]
-            conceptos = [x for x in (perpare_concepto(ym_date, c, lambda x: concepto_adapter(client, x)) for c in f["Conceptos"]) if x]
+            conceptos = [x for x in (prepare_concepto(c) for c in f["Conceptos"]) if x]
             if conceptos:
                 f["Conceptos"] = conceptos
-                yield create_cfdi(client, f, serie, str(folio + i), issuer, lugar_expedicion)
+                yield create_cfdi(client, f, serie, str(folio + i), csd_signer, base_template)
                 i += 1
 
     cfdis = [i for i in facturas_iter()]
@@ -183,12 +186,12 @@ def generate_ingresos(values, issuer, lugar_expedicion, concepto_adapter):
 
 def parse_fecha_pago(fecha_pago):
     if not fecha_pago:
-        logger.error("Fecha de Pago esta vacia")
+        logger.info("Fecha de Pago esta vacia")
         return
 
     fecha_pago = datetime.fromisoformat(fecha_pago)
     if fecha_pago > datetime.now():
-        logger.error("Fecha de Pago esta en el futuro")
+        logger.info("Fecha de Pago esta en el futuro")
         return
 
     if fecha_pago.replace(hour=12) > datetime.now():
@@ -198,30 +201,31 @@ def parse_fecha_pago(fecha_pago):
 
     dif = datetime.now() - fecha_pago
     if dif.days > 30:
-        logger.error("!!! FECHA DE PAGO ES MAYOR A 30 DIAS !!!")
+        logger.info("!!! FECHA DE PAGO ES MAYOR A 30 DIAS !!!")
 
     return fecha_pago
 
 
-def pago_factura(factura_pagar, fecha_pago, forma_pago, issuer, lugar_expedicion):
+def pago_factura(config, factura_pagar, fecha_pago, forma_pago, csd_signer, lugar_expedicion):
     if not (fecha_pago := parse_fecha_pago(fecha_pago)):
         return
 
     i = factura_pagar
     if i.saldo_pendiente != i["Total"]:
-        logger.error("Comprobante ya tiene pago anterior")
-        logger.error(f"Saldo Pendiente: {i.saldo_pendiente}")
+        logger.info("Comprobante ya tiene pago anterior")
+        logger.info(f"Saldo Pendiente: {i.saldo_pendiente}")
         return
 
-    return Comprobante.pago_comprobantes(
-        emisor=issuer,
+    invoice = Comprobante.pago_comprobantes(
         lugar_expedicion=lugar_expedicion,
         comprobantes=i,
         fecha_pago=fecha_pago,
         forma_pago=forma_pago,
         serie=config.serie(),
         folio=str(config.folio()),
-    ).process()
+    )
+    invoice.sign(csd_signer)
+    return invoice.process()
 
     # Pago Parcial
     # comprobantes = [PagoComprobante(
@@ -232,8 +236,8 @@ def pago_factura(factura_pagar, fecha_pago, forma_pago, issuer, lugar_expedicion
     # ) for c, imp_pagado in cfdis],
 
 
-def find_ajustes(mes_ajuste):
-    for f in FacturasManager()["Facturas"]:
+def find_ajustes(facturas, mes_ajuste):
+    for f in facturas:
         rfc = f["Rfc"]
         for concepto in f["Conceptos"]:
             _, mes_aj = parse_periodo_mes_ajuste(concepto['_periodo_mes_ajuste'])
@@ -252,27 +256,27 @@ def exportar_facturas_filename(periodo):
     return archivo_excel
 
 
-def exportar_facturas(all_invoices, periodo, issuer):
+def exportar_facturas(all_invoices, periodo, emisor_rfc, emisor_regimen):
     dp = parse_date_period(periodo)
 
-    emitidas = filter_invoices_iter(invoices=all_invoices.values(), fecha=dp, rfc_emisor=issuer.rfc)
+    emitidas = filter_invoices_iter(invoices=all_invoices.values(), fecha=dp, rfc_emisor=emisor_rfc)
     emitidas_pendientes = filter_invoices_iter(
-        invoices=all_invoices.values(), fecha=lambda x: x <= dp, rfc_emisor=issuer.rfc, estatus='1',
+        invoices=all_invoices.values(), fecha=lambda x: x <= dp, rfc_emisor=emisor_rfc, estatus='1',
         invoice_type="I", pending_balance=lambda x: x > 0)
-    emitidas_pagos = filter_payments_iter(invoices=all_invoices, fecha=dp, rfc_emisor=issuer.rfc)
+    emitidas_pagos = filter_payments_iter(invoices=all_invoices, fecha=dp, rfc_emisor=emisor_rfc)
 
-    recibidas = filter_invoices_iter(invoices=all_invoices.values(), fecha=dp, rfc_receptor=issuer.rfc)
+    recibidas = filter_invoices_iter(invoices=all_invoices.values(), fecha=dp, rfc_receptor=emisor_rfc)
     recibidas_pendientes = filter_invoices_iter(
-        invoices=all_invoices.values(), fecha=lambda x: x <= dp, rfc_receptor=issuer.rfc, estatus='1',
+        invoices=all_invoices.values(), fecha=lambda x: x <= dp, rfc_receptor=emisor_rfc, estatus='1',
         invoice_type="I", pending_balance=lambda x: x > 0)
-    recibidas_pagos = filter_payments_iter(invoices=all_invoices, fecha=dp, rfc_receptor=issuer.rfc)
+    recibidas_pagos = filter_payments_iter(invoices=all_invoices, fecha=dp, rfc_receptor=emisor_rfc)
 
     recibidas_pagos = list(recibidas_pagos)
     pagos_hechos_iva = [
         p
         for p in recibidas_pagos
         if p.impuestos.get("Traslados", {}).get(IVA16, {}).get("Importe", 0) > 0
-           and p.comprobante["Receptor"].get("RegimenFiscalReceptor") in (issuer.tax_system, None)
+           and p.comprobante["Receptor"].get("RegimenFiscalReceptor") in (emisor_regimen, None)
     ]
     prediales = [p for p in recibidas_pagos if p.comprobante["Emisor"]["Rfc"] == "TMT620101EV4"]
 
@@ -291,7 +295,7 @@ def exportar_facturas(all_invoices, periodo, issuer):
     payments_export(workbook, "RECIBIDAS PAGOS", recibidas_pagos)
 
     # SPECIALES
-    payments_export(workbook, f"RECIBIDAS PAGOS IVA {issuer.tax_system.code}", pagos_hechos_iva)
+    payments_export(workbook, f"RECIBIDAS PAGOS IVA {emisor_regimen.code}", pagos_hechos_iva)
     if prediales:
         payments_export(workbook, "PREDIALES", prediales)
 
