@@ -12,7 +12,7 @@ TEXT_PADDING = ((5, 0), 3)
 RTEXT_PADDING = ((0, 0), 3)
 
 
-def make_layout(has_fiel, debug=False):
+def make_layout(has_fiel):
     # LAYOUT
     button_column = [
         sg.Button("Preparar Facturas", key="prepare_facturas", border_width=0),
@@ -97,7 +97,7 @@ def make_layout(has_fiel, debug=False):
         c_second,
         [sg.HSeparator()],
         button_column_third,
-        [sg.Output(expand_x=True, expand_y=True, key="console", echo_stdout_stderr=debug)],
+        [sg.Multiline(expand_x=True, expand_y=True, key="console", write_only=True, autoscroll=True, reroute_stdout=True)],
         button_column_low
     ]
 
