@@ -6,7 +6,6 @@ from uuid import UUID
 import diskcache
 from satcfdi.accounting import SatCFDI
 from satcfdi.pacs import sat
-from .file_data_managers import ConfigManager
 from .log_tools import print_yaml
 
 PUE_PAGADA = 0
@@ -14,7 +13,6 @@ PPD_IGNORAR = 1
 EMAIL_NOTIFICADA = 2
 STATUS_SAT = 3
 
-config = ConfigManager()
 sat_manager = sat.SAT()
 
 logger = logging.getLogger(__name__)
@@ -83,18 +81,22 @@ class LocalDB:
 
 
 class LocalDBSatCFDI(LocalDB):
+    def __init__(self, config):
+        super().__init__()
+        self.config = config
+
     def email_notificada(self, cfdi: SatCFDI):
-        if cfdi["Fecha"] <= config['email_notificada_hasta']:
+        if cfdi["Fecha"] <= self.config['email_notificada_hasta']:
             return True
         return super().email_notificada(cfdi.uuid)
 
     def pue_pagada(self, cfdi: SatCFDI):
-        if cfdi["Fecha"] <= config['pue_pagada_hasta']:
+        if cfdi["Fecha"] <= self.config['pue_pagada_hasta']:
             return True
         return super().pue_pagada(cfdi.uuid)
 
     def ppd_ignorar(self, cfdi: SatCFDI):
-        if cfdi["Fecha"] <= config['ppd_ignorar_hasta']:
+        if cfdi["Fecha"] <= self.config['ppd_ignorar_hasta']:
             return True
         return super().ppd_ignorar(cfdi.uuid)
 
@@ -116,9 +118,6 @@ class LocalDBSatCFDI(LocalDB):
         })
 
 
-local_db = LocalDBSatCFDI()
-
-
 def save_data(file, data):
     with open(os.path.join(DATA_DIR, file), 'wb') as f:
         pickle.dump(data, f)
